@@ -124,7 +124,7 @@ class ZabbixProvider(object):
                 "address" : instance.address,
                 "port" : "80",
                 "regexp" : "WORKING",
-                "uri": "/health-check/redis-con",
+                "uri": "/health-check/redis-con/",
                 "var": "redis-con",
                 "alarm" : "yes",
                 "notes": dbinfra.name,
@@ -135,7 +135,7 @@ class ZabbixProvider(object):
                 "address" : instance.address,
                 "port" : "80",
                 "regexp" : "WORKING",
-                "uri": "/health-check/redis-mem",
+                "uri": "/health-check/redis-mem/",
                 "var": "redis-mem",
                 "alarm" : "yes",
                 "notes": dbinfra.name,
